@@ -2,7 +2,7 @@
  *
  * Copyright (C) 2003-2004  Narcis Ilisei <inarcis2002@hotpop.com>
  * Copyright (C) 2006       Steve Horbachuk
- * Copyright (C) 2010-2020  Joachim Nilsson <troglobit@gmail.com>
+ * Copyright (C) 2010-2021  Joachim Wiberg <troglobit@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -59,7 +59,7 @@ static char *fetch_keys(ddns_t *ctx, ddns_info_t *info)
 	http_trans_t  trans;
 	http_t        client;
 	char          buffer[384];
-	int           i, rc;
+	int           i, rc, level;
 
 	rc = (http_construct(&client));
 	if (rc)
@@ -88,7 +88,11 @@ static char *fetch_keys(ddns_t *ctx, ddns_info_t *info)
 	trans.max_rsp_len = ctx->work_buflen - 1;	/* Save place for a \0 at the end */
 
 	rc = http_transaction(&client, &trans);
-	logit(LOG_DEBUG, "=> %s", trans.rsp_body);
+	if (strstr(trans.rsp_body, "ERROR:"))
+		level = LOG_ERR;
+	else
+		level = LOG_DEBUG;
+	logit(level, "=> %s", trans.rsp_body);
 	http_exit(&client);
 	http_destruct(&client, 1);
 
@@ -110,10 +114,15 @@ static int setup(ddns_t *ctx, ddns_info_t *info, ddns_alias_t *alias)
 
 	tmp = buf = fetch_keys(ctx, info);
 	if (!buf) {
-		logit(LOG_INFO, "Cannot find you FreeDNS account API keys");
+		logit(LOG_ERR, "Cannot find your FreeDNS account API keys");
 		return RC_ERROR;
 	}
 
+	if (strstr(buf, "Failed authenticating to fetch API keys")) {
+		free(buf);
+		return RC_DDNS_RSP_AUTH_FAIL;
+	}
+
 	for (line = strsep(&tmp, "\n"); line; line = strsep(&tmp, "\n")) {
 		int num;
 
