@@ -1,6 +1,6 @@
 /* GnuTLS interface for optional HTTPS functions
  *
- * Copyright (C) 2014-2020  Joachim Nilsson <troglobit@gmail.com>
+ * Copyright (C) 2014-2021  Joachim Wiberg <troglobit@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -124,6 +124,7 @@ static int ssl_set_ca_location(void)
 
 	/* A user defined CA PEM bundle overrides any built-ins or fall-backs */
 	if (ca_trust_file) {
+		logit(LOG_DEBUG, "Using CA PEM bundle: %s", ca_trust_file);
 		num = gnutls_certificate_set_x509_trust_file(xcred, ca_trust_file, GNUTLS_X509_FMT_PEM);
 		goto done;
 	}
@@ -154,11 +155,6 @@ int ssl_init(void)
 
 	/* X509 stuff */
 	gnutls_certificate_allocate_credentials(&xcred);
-
-	/* Try to figure out location of trusted CA certs on system */
-	if (ssl_set_ca_location())
-		return RC_HTTPS_NO_TRUSTED_CA_STORE;
-
 	gnutls_certificate_set_verify_function(xcred, verify_certificate_callback);
 
 	return 0;
@@ -185,29 +181,47 @@ void ssl_get_info(http_t *client)
 #endif
 }
 
+int ssl_fail(http_t *client, int rc)
+{
+	if (!client)
+		return rc;
+
+	ssl_close(client);
+
+	return rc;
+}
 
 int ssl_open(http_t *client, char *msg)
 {
-	int ret;
-	char buf[256];
-	size_t len;
-	const char *sn, *err;
 	const gnutls_datum_t *cert_list;
 	unsigned int cert_list_size = 0;
 	gnutls_x509_crt_t cert;
+	const char *sn, *err;
+	char buf[256];
+	int port = 0;
+	size_t len;
+	int ret;
 
 	if (!client->ssl_enabled)
 		return tcp_init(&client->tcp, msg);
 
+	/* Try to figure out location of trusted CA certs on system */
+	if (ssl_set_ca_location())
+		return RC_HTTPS_NO_TRUSTED_CA_STORE;
+
 	/* Initialize TLS session */
 	logit(LOG_INFO, "%s, initiating HTTPS ...", msg);
-	gnutls_init(&client->ssl, GNUTLS_CLIENT);
+	ret = gnutls_init(&client->ssl, GNUTLS_CLIENT);
+	if (ret) {
+		logit(LOG_ERR, "Failed initializing HTTPS: %s", gnutls_strerror(ret));
+		return RC_HTTPS_OUT_OF_MEMORY;
+	}
 
 	/* SSL SNI support: tell the servername we want to speak to */
 	http_get_remote_name(client, &sn);
 	gnutls_session_set_ptr(client->ssl, (void *)sn);
 	if (gnutls_server_name_set(client->ssl, GNUTLS_NAME_DNS, sn, strlen(sn)))
-		return RC_HTTPS_SNI_ERROR;
+		return ssl_fail(client, RC_HTTPS_SNI_ERROR);
 
 	/* Use default priorities */
 	ret = gnutls_priority_set_direct(client->ssl, "NORMAL", &err);
@@ -215,14 +229,16 @@ int ssl_open(http_t *client, char *msg)
 		if (ret == GNUTLS_E_INVALID_REQUEST)
 			logit(LOG_ERR, "Syntax error at: %s", err);
 
-		return RC_HTTPS_INVALID_REQUEST;
+		return ssl_fail(client, RC_HTTPS_INVALID_REQUEST);
 	}
 
 	/* put the x509 credentials to the current session */
 	gnutls_credentials_set(client->ssl, GNUTLS_CRD_CERTIFICATE, xcred);
 
 	/* connect to the peer */
-	tcp_set_port(&client->tcp, HTTPS_DEFAULT_PORT);
+	http_get_port(client, &port);
+	if (!port)
+		http_set_port(client, HTTPS_DEFAULT_PORT);
 	DO(tcp_init(&client->tcp, msg));
 
 	/* Forward TCP socket to GnuTLS, the set_int() API is perhaps too new still ... since 3.1.9 */
@@ -237,16 +253,17 @@ int ssl_open(http_t *client, char *msg)
 
 	if (gnutls_error_is_fatal(ret)) {
 		logit(LOG_ERR, "SSL handshake with %s failed: %s", sn, gnutls_strerror(ret));
-		return RC_HTTPS_FAILED_CONNECT;
+		return ssl_fail(client, RC_HTTPS_FAILED_CONNECT);
 	}
 
+	client->connected = 1;
 	ssl_get_info(client);
 
 	/* Get server's certificate (note: beware of dynamic allocation) - opt */
 	cert_list = gnutls_certificate_get_peers(client->ssl, &cert_list_size);
 	if (cert_list_size > 0) {
 		if (gnutls_x509_crt_init(&cert))
-			return RC_HTTPS_FAILED_GETTING_CERT;
+			return ssl_fail(client, RC_HTTPS_FAILED_GETTING_CERT);
 
 		gnutls_x509_crt_import(cert, &cert_list[0], GNUTLS_X509_FMT_DER);
 
@@ -267,9 +284,11 @@ int ssl_open(http_t *client, char *msg)
 int ssl_close(http_t *client)
 {
 	if (client->ssl_enabled) {
-		gnutls_bye(client->ssl, GNUTLS_SHUT_WR);
+		if (client->connected)
+			gnutls_bye(client->ssl, GNUTLS_SHUT_WR);
 		gnutls_deinit(client->ssl);
 	}
+	client->connected = 0;
 
 	return tcp_exit(&client->tcp);
 }
@@ -285,8 +304,10 @@ int ssl_send(http_t *client, const char *buf, int len)
 		ret = gnutls_record_send(client->ssl, buf, len);
 	} while (ret == GNUTLS_E_INTERRUPTED || ret == GNUTLS_E_AGAIN);
 
-	if (ret < 0)
+	if (ret < 0) {
+		logit(LOG_WARNING, "Failed sending HTTPS request: %s", gnutls_strerror(ret));
 		return RC_HTTPS_SEND_ERROR;
+	}
 
 	logit(LOG_DEBUG, "Successfully sent HTTPS request!");
 
